@@ -6,8 +6,8 @@ function (model) {
   if (!is.null(model$xlevels)) {
     variables <- colnames(m.frame)[which(colnames(m.frame)%in%names(model$xlevels))]
     if (length(variables)<ncol(m.frame)) {
-	covar <- as.data.frame(m.frame[,colnames(m.frame)!=variables])
-	names(covar) <- colnames(m.frame)[which(colnames(m.frame)!=variables)]
+	covar <- as.data.frame(m.frame[,!colnames(m.frame)%in%variables])
+	names(covar) <- colnames(m.frame)[!colnames(m.frame)%in%variables]
     } else {
 	stop("no covariable in the model")
     }
@@ -16,12 +16,12 @@ function (model) {
   }
   res <- residuals(model,type="martingale")
   if (ncol(covar)>1) {
-    par(mfrow = c(ceiling(ncol(covar)/2), 2))
+    par(mfrow=n2mfrow(ncol(covar)))
   }
   for (i in 1:ncol(covar)) {
-    plot(covar[, i], res, xlab = colnames(covar)[i], ylab = "Martingale residuals")
-    abline(h = 0, lty = 3, col = "grey")
-    panel.smooth(covar[, i], res)
+    plot(covar[,i],res,xlab=colnames(covar)[i],ylab="Martingale residuals")
+    abline(h=0,lty=3,col="grey")
+    panel.smooth(covar[,i],res)
   }
 }
 
